/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2012 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.role.provider;

import javax.annotation.Nonnull;
import java.util.Collection;
import java.util.Collections;
import org.openide.util.Lookup;
import it.tidalwave.netbeans.role.provider.impl.ReflectionUtils;

/***********************************************************************************************************************
 *
 * A convenience implementatior of {@link CapabilitiesProvider} that returns empty collections. Subclasses of this class
 * are not forced to implements all the methods, they just need to override the relevant ones.
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public abstract class RoleProviderSupport<T> implements RoleProvider<T>
  {
    @Nonnull
    private final Class<T> ownerClass;

    public RoleProviderSupport()
      {
        ownerClass = (Class<T>)ReflectionUtils.getTypeArguments(RoleProviderSupport.class, getClass()).get(0);
      }

    /** {@inheritDocs} */
    @Override @Nonnull
    public final Class<T> getOwnerClass()
      {
        return ownerClass;
      }
    
    /** {@inheritDocs} */
    @Override @Nonnull
    public Collection<? extends Object> createRoles (final @Nonnull T owner)
      {
        return Collections.emptyList();
      }

    /** {@inheritDocs} */
    @Override @Nonnull
    public Collection<? extends Lookup> createLookups (final @Nonnull T owner)
      {
        return Collections.emptyList();
      }
  }
